import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import ProjectItem from './item'
import Banner from './banner'
import ActivityItem from '../activity/item'

import ready from '@utils/ready'

import { queryBanners, savePoint } from '@services/common'
import { queryNewsList } from '@services/news'
import { queryActivityList } from '@services/activity'
import { dispatchCitySelected } from '@actions/city'
import { ROLE_CODE } from '@constants/user'
import { connect } from '@tarojs/redux'
import * as actions from '@actions/project'

import QQMapWX from '@lib/qqmap-wx-jssdk.min'
import Notice from '@components/Notice'

@connect(
  state => ({ ...state.project, ...state.city, ...state.user }),
  { ...actions, dispatchCitySelected }
)

export default class Index extends Component {
  config = {
    navigationBarTitleText: '橙蕉'
  }

  state = {
    maskVisible: false,
    keywords: '',
    loaded: false,
    maskBanner: '',
    shareImg: 'https://estateagents.oss-cn-shanghai.aliyuncs.com/miniapp/upload/images/1565358322510-share.jpg',
    bannerList: [],
    newsList: [],
    activityList: [],
    recordId: null,
    visBanner: false,
    indicatorDots: false,
    vertical: true
  }

  componentWillMount() {
    this.qqmapsdk = new QQMapWX({
      key: 'TIIBZ-ZJG33-52T3L-Y3X4Q-NWKLV-KUB3B'
    })

    ready.queue(() => {
      this.loadOpenScreenBanner()
      this.getLocation()

      savePoint({
        event: 'index',
        eventType: 'main',
        propertyName: '进入首页',
        data: '{}'
      }).then(res => {
        this.setState({
          recordId: res.recordId
        })
        console.log('进入首页')
      })
    })
  }
  componentDidShow() {
    if (this.props.curCity.id) {
      ready.queue(() => {
        this.loadData()
      })
    }
  }

  getLocation() {
    const { cityList } = this.props
    Taro.getLocation().then(location => {
      Taro.setStorageSync('lat', location.latitude)
      Taro.setStorageSync('lon', location.longitude)
      this.qqmapsdk.reverseGeocoder({
        location,
        success: (res) => {
          let city = res.result.address_component.city
          let curCity = cityList.filter(item => {
            return item.name == city
          })
          this.updateCity(curCity[0] || cityList[0])
        },
        fail: (error) => {
          this.updateCity(cityList[0])
        },
      })
    }).catch(err => {
      this.updateCity(cityList[0])
    })
  }

  updateCity(payload) {
    this.props.dispatchCitySelected(payload).then(res => {
      this.loadData()
    })
  }

  loadData() {
    this.loadBannerList()
    this.loadNewsList()
    this.loadActivityList()
    this.loadList()
  }

  loadOpenScreenBanner() {
    const payload = {
      // showPosition: 'index'
    }
    // 获取开屏广告图
    queryBanners('screen', payload).then(res => {
      const banner = res[0]
      if (banner) {
        Taro.hideTabBar({
          animation: true
        })
      }
      this.setState({
        maskVisible: banner ? true : false,
        maskBanner: banner
      })
    })
  }
  loadBannerList() {
    const { curCity } = this.props
    // 获取首页banner
    const payload = {
      showPosition: 'index'
    }
    if (curCity.id) {
      payload.cityId = curCity.id
    }
    this.setState({
      visBanner: false
    })
    queryBanners('banner', payload).then(res => {
      this.setState({
        visBanner: true,
        bannerList: res || [],
      })
    })
  }

  loadNewsList() {
    const { curCity } = this.props
    const payload = {
      pageNumber: 1,
      pageSize: 2
    }
    if (curCity.id) {
      payload.cityId = curCity.id
    }
    queryNewsList(payload).then(res => {
      this.setState({
        newsList: res.records || []
      })
    })
  }

  loadActivityList() {
    const { curCity } = this.props
    const payload = {
      pageNumber: 1,
      pageSize: 1
    }
    if (curCity.id) {
      payload.cityId = curCity.id
    }
    queryActivityList(payload).then(res => {
      this.setState({
        activityList: res.list || []
      }, () => {
        console.log(this.state.activityList)
      })
    })
  }

  loadList() {
    const { keywords } = this.state
    const { curCity } = this.props

    const payload = {
      name: keywords
    }
    if (curCity.id) {
      payload.cityId = curCity.id
    }
    Taro.showLoading()
    this.props.dispatchProjectList(payload).then(res => {
      if (!this.state.loaded && res.records.length <= 0) {
        let city = {
          name: '南京市',
          id: 320100
        }
        this.updateCity(city)
        return
      }
      Taro.hideLoading()
      this.setState({
        loaded: true
      })
    })
  }


  //   转发
  onShareAppMessage = () => {
    const {
      userInfo: { person: { personId } }
    } = this.props

    savePoint({
      event: 'share',
      eventType: 'main',
      propertyName: '首页分享',
      data: '{}'
    }).then(res => {
      console.log('首页分享')
    })
    return {
      title: '橙蕉 精准获客平台',//分享内容
      path: `/pages/project/index?from=share&recommender=${personId}`,//分享地址
      imageUrl: this.state.shareImg
    }
  }

  onViewDetail(item) {
    Taro.navigateTo({
      url: `/pages/project/detail/index?id=${item.buildingId}`
    })
  }

  goPerson() {
    Taro.navigateTo({
      url: `/pages/person/index`
    })
  }

  handleBannerClick(item) {
    Taro.navigateTo({
      url: `/pages/project/detail/index?id=${item.buildingId}`
    })
  }

  handleMaskClose() {
    this.setState({
      maskVisible: false
    })
    Taro.showTabBar({
      animation: true
    })
  }

  makePhoneCall = () => {
    // App.zhuge.track('点击电话咨询')
    Taro.makePhoneCall({
      phoneNumber: '0772-6861111'
    })

    savePoint({
      event: 'phone',
      eventType: 'main',
      propertyName: '点击电话咨询',
      data: '{}'
    }).then(res => {
      console.log('点击电话咨询')
    })
  }

  handleMaskBannerClick(data) {
    Taro.navigateTo({
      url: '/pages/project/detail/index?id=' + data.buildingId
    })
    // App.zhuge.track('点击首页banner')
  }

  handleToolsClick() {
    // App.zhuge.track('进入房贷计算器')
    Taro.navigateTo({
      url: `/pages/toolKit/index`
    })
  }

  handleNewsMoreClick() {
    Taro.navigateTo({
      url: `/pages/news/index`
    })
  }

  handNewsItemClick(id) {
    Taro.navigateTo({
      url: '/pages/news/detail/index?id=' + id
    })
  }

  handleActivityItemClick(item) {
    // App.zhuge.track('点击活动')
    Taro.navigateTo({
      url: `/pages/activity/detail/index?id=${item.dynamicId}&buildingId=${item.buildingId}`
    })
  }

  handleActivityMoreClick(item) {
    Taro.navigateTo({
      url: `/pages/activity/index`
    })
  }

  handleLocationClick() {
    Taro.navigateTo({
      url: `/pages/city/index`
    })
  }

  handleToHouseList() {
    Taro.navigateTo({
      url: '/pages/project/list/index'
    })
  }

  handleProItemClick() {
    Taro.navigateTo({
      url: '/pages/project/list/index'
    })
  }
  purchasingPolicy = () => {
    Taro.navigateTo({
      url: `/pages/policy/index`
    })
  }
  toRecomonedPage() {
    const {
      userInfo: { person: { personType } }
    } = this.props
    if (personType === ROLE_CODE['DRIFT'] || personType === ROLE_CODE['CUSTOMER'] || !personType) {
      // 游客或者客户 区别是否有电话
      Taro.navigateTo({
        url: `/pages/agent/become/index`
      })
    } else {
      Taro.navigateTo({
        url: `/pages/agent/recommend/index?type=index`
      })
    }
  }
  toMapHouse() {
    Taro.navigateTo({
      url: `/pages/project/map/index`
    })
  }
  renderActivities() {
    const { activityList } = this.state
    return (
      <Block>
        {/* {
          activityList.length > 0 && (
            <View className="section activity">
              <View className="section-head">
                <Text className="section-head__title">热门活动</Text>
                <View className="section-head__more" onClick={this.handleActivityMoreClick}>
                  更多活动<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <View className="section-content">
                {
                  activityList.map(item => (
                    <ActivityItem
                      data={item}
                      style={{
                        marginBottom: 0
                      }}
                      key={item.dynamicId}
                      onClick={this.handleActivityItemClick.bind(this, item)}>
                    </ActivityItem>
                  ))
                }
              </View>
            </View>
          )
        } */}
      </Block>
    )
  }

  renderProjectList() {
    const { proList: { records } } = this.props
    return (
      <Block>
        {
          records.length > 0 && (
            < View className="section houses" >
              <View className="section-head">
              <View>
                <Text className="section-head__title">全部楼盘
                </Text>
                <Image src={require('@assets/index/map.png')} onClick={this.toMapHouse} className='map-img'></Image>
                  <Text className='map-txt' onClick={this.toMapHouse}>地图看房</Text>
                </View>
                <View className="section-head__more" onClick={this.handleProItemClick}>
                  查看更多<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <View className="section-content">
                {records.map(item => (
                  <ProjectItem
                    key={item.buildingId}
                    onClick={this.onViewDetail.bind(this, item)}
                    data={item}
                  />
                ))}
              </View>
            </View >
          )
        }
        <Image className="advertisement" src={require('@assets/shop/banner1.jpg')}></Image>
        <View className="last-text">已经到底了~</View>
      </Block>
    )
  }

  renderMaskBanner() {
    const { maskBanner } = this.state
    return (
      <View className="mask-banner">
        <View className="content">
          <Image
            mode="widthFix"
            className="img"
            src={maskBanner.image}
            onClick={this.handleMaskBannerClick.bind(this, maskBanner)}>
          </Image>
          <Icon className="iconfont close icon-buoumaotubiao20" onClick={this.handleMaskClose}></Icon>
        </View>
      </View>
    )
  }

  renderNews() {
    const { newsList } = this.state
    return (
      <Block>
        {
          newsList.length > 0 && (
            <View className="section news">
              <View className="section-head">
                <Text className="section-head__title">新鲜资讯</Text>
                <View className="section-head__more" onClick={this.handleNewsMoreClick}>
                  更多资讯<Text className="iconfont icon-more"></Text>
                </View>
              </View>
              <View className="section-content">
                {
                  newsList.map(item => (
                    <View className="news-item" key={item.newsId} onClick={this.handNewsItemClick.bind(this, item.newsId)}>
                      <Image src={item.newsImg} mode="aspectFill" className="news-item__pic"></Image>
                      <View className="news-item__title">{item.newsName}</View>
                    </View>
                  ))
                }
              </View>
            </View>
          )
        }
      </Block>
    )
  }

  render() {
    const { curCity } = this.props
    const { newsList } = this.state
    const { userInfo: { person: { personType } } } = this.props

    return (
      <Block>
        {this.state.loaded && (
          <View className="page">
            <Notice></Notice>
            <ScrollView
              scrollY
              className='home'>
              <View className="section section-top" style={{ marginTop: 0, paddingTop: 0 }}>
                <View
                  style={{
                    height: '250px', position: 'relative'
                  }}>
                  {
                    this.state.visBanner && (
                      <Banner
                        style={{
                          borderRadius: '3px',
                          height: '250px'
                        }}
                        indicatorDots={false}
                        list={this.state.bannerList}
                        onClick={this.handleBannerClick}>
                      </Banner>
                    )
                  }
                </View>
                <View className="search" onClick={this.handleToHouseList}>
                  <Text className="search-icon icon-sousuo iconfont"></Text>
                  <Input className="search-input" placeholder="输入你想查询的楼盘"></Input>
                </View>
                <View className="location" onClick={this.handleLocationClick}>
                  <Text className="location-icon iconfont icon-daohangdizhi"></Text>
                  <Text className="location-text">{curCity.id ? curCity.name : '正在定位'}</Text>
                </View>
                {
                  (personType !== ROLE_CODE['CONSULTANT']) && (
                    <View className='section sectionn-customer' >
                      <View className='section-content' onClick={this.toRecomonedPage.bind(this, personType)}>
                        <Image src={require('@assets/index/logo.png')} className='logo_img' mode="widthFix"></Image>
                        <View className='section-content_title'>
                          <Text>推荐客户 赢积分好礼</Text>
                          <Text>更多惊喜在积分商城等着你</Text>
                        </View>
                        <Image src={require('@assets/index/recommend.png')} className='section-content_img' mode="widthFix"></Image>
                      </View>
                    </View>
                  )
                }
                {/* 工具箱 */}
                {/* <View className="tools">
                  <View className="section-head">
                    <Text className="section-head__title">橙蕉</Text>
                    <View className="section-head__more">更多服务</View>
                  </View>
                  <View className='tools-main'>
                    <View className='tools-item' onClick={this.handleProItemClick}>
                      <Image src={require('@assets/loupan.png')} className='tools-item-img'></Image>
                      <Text className='tools-item-txt'>楼盘展示</Text>
                    </View> */}
                {/* <View className='tools-item' onClick={this.purchasingPolicy}>
                      <Image src={require('@assets/jianli.png')} className='tools-item-img'></Image>
                      <Text className='tools-item-txt'>购房政策</Text>
                    </View> */}
                {/* <View className='tools-item' onClick={this.handleToolsClick}>
                      <Image src={require('@assets/jisuanqi.png')} className='tools-item-img'></Image>
                      <Text className='tools-item-txt'>房贷计算</Text>
                    </View>
                    <View className='tools-item' onClick={this.toMapHouse}>
                      <Image src={require('@assets/didian.png')} className='tools-item-img'></Image>
                      <Text className='tools-item-txt'>地图看房</Text>
                    </View>
                  </View>
                </View> */}


              </View>
              {/* 资讯 */}
              {/* {
                newsList.length > 0 && (<View className='section sectionn-news' onClick={this.handleNewsMoreClick}>
                  <Image src={require('@assets/zixun.png')} className='sectionn-news_img' mode="widthFix"></Image>
                  <View className='sectionn-news-list'>
                    <Swiper
                      className='test-h'
                      indicatorColor='#999'
                      indicatorActiveColor='#333'
                      vertical={vertical}
                      circular
                      indicatorDots={indicatorDots}
                      autoplay>
                      {
                        newsList.map(item => (
                          <SwiperItem key={item.newsId}>
                            <Text className='sectionn-news_txt'>{item.newsName}</Text>
                          </SwiperItem>
                        ))
                      }
                    </Swiper>
                  </View>
                </View>)
              } */}

              {/* 推荐客户 */}



              {/* 热门活动 */}
              {this.renderActivities()}

              {/* 新鲜资讯 */}
              {/* {this.renderNews()} */}

              {/* 推荐楼盘 */}
              {this.renderProjectList()}

            </ScrollView>

            {this.state.maskVisible && this.renderMaskBanner()}
          </View >
        )}
      </Block>
    )
  }
}